@@ -2,9 +2,9 @@
 #
 #  Net::Server - Extensible Perl internet server
 #
-#  $Id: Server.pm,v 1.153 2012/06/20 22:44:58 rhandom Exp $
+#  $Id: Server.pm,v 1.158 2013/01/10 07:37:17 rhandom Exp $
 #
-#  Copyright (C) 2001-2012
+#  Copyright (C) 2001-2013
 #
 #    Paul Seamons
 #    paul@seamons.com
@@ -32,7 +32,7 @@ use Net::Server::Proto ();
 use Net::Server::Daemonize qw(check_pid_file create_pid_file safe_fork
                               get_uid get_gid set_uid set_gid);
 
-our $VERSION = '2.006';
+our $VERSION = '2.007';
 
 sub new {
     my $class = shift || die "Missing class";
@@ -105,13 +105,8 @@ sub commandline {
 
 sub _get_commandline {
     my $self = shift;
-    if (open my $fh, "<", "/proc/$$/cmdline") { # see if we can find the full command line - unix specific
-        my $line = do { local $/ = undef; <$fh> };
-        close $fh;
-        return [split /\0/, $1] if $line =~ /^(.+)$/; # need to untaint to allow for later hup
-    }
     my $script = $0;
-    $script = $ENV{'PWD'} .'/'. $script if $script =~ m|^[^/]+/| && $ENV{'PWD'}; # add absolute to relative
+    $script = $ENV{'PWD'} .'/'. $script if $script =~ m|^[^/]+/| && $ENV{'PWD'}; # add absolute to relative - avoid Cwd
     $script =~ /^(.+)$/; # untaint for later use in hup
     return [$1, @ARGV]
 }
@@ -587,7 +582,8 @@ sub allow_deny {
 
     # if the addr or host matches a deny, reject it immediately
     foreach (@{ $prop->{'deny'} }) {
-        return 0 if $prop->{'peerhost'} =~ /^$_$/ && defined $prop->{'reverse_lookups'};
+        return 0 if $prop->{'reverse_lookups'}
+            && defined($prop->{'peerhost'}) && $prop->{'peerhost'} =~ /^$_$/;
         return 0 if $peeraddr =~ /^$_$/;
     }
     if (@{ $prop->{'cidr_deny'} }) {
@@ -597,7 +593,8 @@ sub allow_deny {
 
     # if the addr or host isn't blocked yet, allow it if it is allowed
     foreach (@{ $prop->{'allow'} }) {
-        return 1 if $prop->{'peerhost'} =~ /^$_$/ && defined $prop->{'reverse_lookups'};
+        return 1 if $prop->{'reverse_lookups'}
+            && defined($prop->{'peerhost'}) && $prop->{'peerhost'} =~ /^$_$/;
         return 1 if $peeraddr =~ /^$_$/;
     }
     if (@{ $prop->{'cidr_allow'} }) {
@@ -674,15 +671,27 @@ sub done {
     return $self->{'server'}->{'done'};
 }
 
+sub pre_fork_hook {}
+sub child_init_hook {}
+sub child_finish_hook {}
 
 sub run_dequeue { # fork off a child process to handle dequeuing
     my $self = shift;
+    $self->pre_fork_hook('dequeue');
     my $pid  = fork;
     $self->fatal("Bad fork [$!]") if ! defined $pid;
     if (!$pid) { # child
+        $SIG{'INT'} = $SIG{'TERM'} = $SIG{'QUIT'} = $SIG{'HUP'} = sub {
+            $self->child_finish_hook('dequeue');
+            exit;
+        };
+        $SIG{'PIPE'} = $SIG{'TTIN'} = $SIG{'TTOU'} = 'DEFAULT';
+        $self->child_init_hook('dequeue');
         $self->dequeue();
+        $self->child_finish_hook('dequeue');
         exit;
     }
+    $self->log(4, "Running dequeue child $pid");
 
     $self->{'server'}->{'children'}->{$pid}->{'status'} = 'dequeue'
         if $self->{'server'}->{'children'};
@@ -714,7 +723,7 @@ sub server_close {
 
     $self->pre_server_close_hook;
 
-    $self->log(2,$self->log_time . " Server closing!");
+    $self->log(2, $self->log_time . " Server closing!");
 
     if ($prop->{'kind_quit'} && $prop->{'children'}) {
         $self->log(3, "Attempting a slow shutdown");
@@ -728,7 +737,7 @@ sub server_close {
         }
     }
 
-    if (defined($prop->{'_HUP'}) && $prop->{'leave_children_open_on_hup'}) {
+    if ($prop->{'_HUP'} && $prop->{'leave_children_open_on_hup'}) {
         $self->hup_children;
 
     } else {
@@ -743,12 +752,12 @@ sub server_close {
     }
     if (defined($prop->{'pid_file'})
         && -e $prop->{'pid_file'}
-        && !defined($prop->{'_HUP'})
+        && !$prop->{'_HUP'}
         && defined($prop->{'pid_file_unlink'})) {
         unlink($prop->{'pid_file'}) || $self->log(1, "Couldn't unlink \"$prop->{'pid_file'}\" [$!]");
     }
 
-    if (defined $prop->{'_HUP'}) {
+    if ($prop->{'_HUP'}) {
         $self->restart_close_hook();
         $self->hup_server; # execs at the end
     }
@@ -790,10 +799,10 @@ sub close_parent {
 sub close_children {
     my $self = shift;
     my $prop = $self->{'server'};
-
     return unless $prop->{'children'} && scalar keys %{ $prop->{'children'} };
 
     foreach my $pid (keys %{ $prop->{'children'} }) {
+        $self->log(4, "Kill TERM pid $pid");
         if (kill(15, $pid) || ! kill(0, $pid)) { # if it is killable, kill it
             $self->delete_child($pid);
         }
@@ -808,12 +817,14 @@ sub is_prefork { 0 }
 sub hup_children {
     my $self = shift;
     my $prop = $self->{'server'};
-
     return unless defined $prop->{'children'} && scalar keys %{ $prop->{'children'} };
     return if ! $self->is_prefork;
     $self->log(2, "Sending children hup signal");
 
-    kill(1, $_) for keys %{ $prop->{'children'} };
+    for my $pid (keys %{ $prop->{'children'} }) {
+        $self->log(4, "Kill HUP pid $pid");
+        kill(1, $pid) or $self->log(2, "Failed to kill pid $pid: $!");
+    }
 }
 
 sub post_child_cleanup_hook {}
@@ -824,6 +835,8 @@ sub sig_hup {
     my $self = shift;
     my $prop = $self->{'server'};
 
+    $self->log(2, "Received a SIG HUP");
+
     my $i  = 0;
     my @fd;
     $prop->{'_HUP'} = [];
@@ -856,7 +869,7 @@ sub sig_hup {
 
 sub hup_server {
     my $self = shift;
-    $self->log(0, $self->log_time()." HUP'ing server");
+    $self->log(0, $self->log_time()." Re-exec server during HUP");
     delete @ENV{$self->hup_delete_env_keys};
     exec @{ $self->commandline };
 }
